if select(2, UnitClass("player")) ~= "DRUID" then return end
local GetSpellInfo = DrDamage.SafeGetSpellInfo
local GetCombatRatingBonus = GetCombatRatingBonus
local GetCritChance = GetCritChance
local GetShapeshiftForm = GetShapeshiftForm
local UnitExists = UnitExists
local UnitIsFriend = UnitIsFriend
local UnitIsUnit = UnitIsUnit
local UnitBuff = UnitBuff
local UnitHealth = UnitHealth
local UnitHealthMax = UnitHealthMax
local UnitPower = UnitPower
local UnitPowerMax = UnitPowerMax
local math_floor = math.floor
local math_abs = math.abs
local math_min = math.min
local math_max = math.max
local select = select
local tonumber = tonumber
local IsSpellKnown = IsSpellKnown

function DrDamage:PlayerData()
	--Health updates
	self.TargetHealth = { [1] = 0.5, [0.5] = GetSpellInfo(774), [2] = 0.8, [0.8] = GetSpellInfo(6785) }
	--Events
	local lastEnergy = 0
	local ferocious_bite = GetSpellInfo(22568)
	self.Calculation["UNIT_POWER"] = function()
		local energy = UnitPower("player",3)
		if (energy < 65) and (lastEnergy > 65 or math_abs(energy - lastEnergy) >= 20) or (energy >= 65 and lastEnergy < 65) then
			lastEnergy = energy
			self:UpdateAB(ferocious_bite)
		end
	end
	--Innervate
	local dreamstate_talent = GetSpellInfo(33597)
	self.ClassSpecials[GetSpellInfo(29166)] = function()
		return (0.2 + select(self.talents[dreamstate_talent] or 3,0.15,0.3,0)) * UnitPowerMax("player",0), nil, true
	end
--GENERAL
	self.Calculation["Stats"] = function( calculation, ActiveAuras, Talents, spell, baseSpell )
		local mastery = calculation.mastery
		local masteryLast = calculation.masteryLast
		local spec = calculation.spec
		if spec == 1 then
			if mastery > 0 and mastery ~= masteryLast then
				if ActiveAuras["Eclipse"] then
					--NOTE: Eclipse added in aura module if no mastery present
					local eclipse = 1.15
					--Mastery: Total Eclipse
					local bonus = mastery * 0.01 
					calculation.dmgM = calculation.dmgM * (eclipse + bonus)
					calculation.masteryLast = mastery
					calculation.masteryBonus = bonus
				end
			end
		elseif spec == 2 then
			if mastery > 0 and mastery ~= masteryLast then
				if (ActiveAuras["Cat Form"] and (calculation.spellName == "Rake" or calculation.spellName == "Rip" or calculation.spellName == "Thrash (Cat)" or calculation.spellName == "Pounce" or calculation.spellName == "Thrash (Bear)")) then
					local masteryBonus = calculation.masteryBonus
					if masteryBonus then
						calculation.bleedBonus = calculation.bleedBonus / masteryBonus
					end
					local bonus = 1 + (mastery * 0.01)
					calculation.bleedBonus = calculation.bleedBonus * bonus
					calculation.masteryLast = mastery
					calculation.masteryBonus = bonus
				end
			end
		elseif spec == 4 then
			--Naturalist - and only applies to heals.
			--Currently on 5.2 PTR
			if mastery > 0 and mastery ~= masteryLast then
				if calculation.healingSpell then
					mastery, mycoefficient = GetMasteryEffect()
					local masteryBonus = mastery
					--Mastery: Harmony
					local bonus = 1 + (mastery * 0.01) 
					if calculation.spellName == "Healing Touch" or calculation.spellName == "Nourish" or calculation.spellName == "Swiftmend" then
						if masteryBonus then
							calculation.dmgM_dd = calculation.dmgM_dd / masteryBonus
						end
						calculation.dmgM_dd = calculation.dmgM_dd * bonus
						calculation.masteryBonus = bonus
					elseif calculation.spellName == "Regrowth" then
						if masteryBonus then
							calculation.dmgM_dd = calculation.dmgM_dd / masteryBonus
						end
						if calculation.masteryBonus2 then
							calculation.dmgM_dot = calculation.dmgM_dot / calculation.masteryBonus2
						end
						calculation.dmgM_dd = calculation.dmgM_dd * bonus
						calculation.masteryBonus = bonus
						if ActiveAuras["Harmony"] then
							calculation.dmgM_dot = calculation.dmgM_dot * bonus
							calculation.masteryBonus2 = bonus
						end
					--elseif ActiveAuras["Harmony"] then
					--	if masteryBonus then
					--		calculation.dmgM_dot = calculation.dmgM_dot / masteryBonus
					--	end
					--	calculation.dmgM_dot = calculation.dmgM_dot * bonus
					--	calculation.masteryBonus = bonus						
					end
					calculation.masteryLast = mastery
				end
			end
		end
		if calculation.spi ~= 0 then
			if IsSpellKnown(33596) then
				--Increases your spell hit rating by an additional amount equal to 50/100% of your Spirit.
				local rating = calculation.spi 
				calculation.hitPerc = calculation.hitPerc + self:GetRating("Hit", rating, true)
			end
		end
		if calculation.agi ~= 0 then
			--Nurturing Instinct
			if IsSpellKnown(33883) then	
				calculation.SP_mod = calculation.SP_mod + calculation.agi
			end
		end
	end
	local moonfury = { ["Wrath"] = true, ["Moonfire"] = true, ["Starfire"] = true, ["Starsurge"] = true, ["Insect Swarm"] = true, ["Starfall"] = true }
	self.Calculation["DRUID"] = function( calculation, ActiveAuras, Talents, spell, baseSpell )
		--Stat mods
		--[[if Talents["Heart of the Wild"] and ActiveAuras["Cat Form"] then
			--While in Cat Form your attack power is increased by 3/7/10%.
			calculation.APM = calculation.APM * (1 + Talents["Heart of the Wild"])
		end --]]
		--Specialization
		local spec = calculation.spec
		if spec == 1 then
			--TODO: Check specialization is active
			if IsSpellKnown(86530) then
				calculation.intM = calculation.intM * 1.05
			end
			if not calculation.healingSpell then
				if (calculation.school == "Nature" or calculation.school == "Arcane" or calculation.school == "Spellstorm") then
					--Passive: Moonfury
					calculation.dmgM = calculation.dmgM * 1.1
				end
				if moonfury[calculation.spellName] then
					calculation.critM = calculation.critM + 0.5
				end
			end
		elseif spec == 2 then
			--TODO: Check specialization is active
			if ActiveAuras["Cat Form"] and IsSpellKnown(86530) then
				calculation.agiM = calculation.agiM * 1.05
			end
			calculation.APM = calculation.APM * 1.25
		elseif spec == 4 then
			--TODO: Check specialization is active
			if IsSpellKnown(86530) then
				calculation.intM = calculation.intM * 1.05
			end
		end
		if calculation.healingSpell then
			--Glyph of Frenzied Regeneration 4.0 (multiplicative - 3.3.3)
			if ActiveAuras["Frenzied Regeneration"] and self:HasGlyph(54810) then
				calculation.dmgM = calculation.dmgM * 1.4
			end
			--if ActiveAuras["Tree of Life"] then
			--	calculation.dmgM = calculation.dmgM * 1.15
			--end
		else
			if ActiveAuras["Moonkin Form"] and (calculation.school == "Arcane" or calculation.school == "Nature" or calculation.school == "Spellstorm") then
				calculation.dmgM = calculation.dmgM * 1.1
			end
		end
	end
--ABILITIES
	--local tol = GetSpellInfo(48371)
	self.Calculation["Lifebloom"] = function( calculation, ActiveAuras, Talents )
		--[[if UnitIsUnit(calculation.target, "player") then
			if Talents["Master Shapeshifter"] and (GetShapeshiftForm() == 0 or ActiveAuras["Tree of Life"]) then
				calculation.dmgM = calculation.dmgM * 1.04
			end
		else
			if Talents["Master Shapeshifter"] and (GetShapeshiftForm() == 0 or ActiveAuras["Tree of Life"]) then
				calculation.dmgM_dot = calculation.dmgM_dot * 1.04
			end
			--if UnitBuff("target",tol) then
			--	calculation.dmgM_dd = calculation.dmgM_dd * 1.04
			--end
		end --]]
		--Glyph of Lifebloom - 4.0
		if self:HasGlyph(54826) then
			calculation.critPerc = calculation.critPerc + 10
		end
	end
	self.Calculation["Nourish"] = function( calculation, ActiveAuras )
		--Nourish bonus if Rejuvenation, Regrowth, Lifebloom, Wild Growth or Tranquility are active on the target
		local hotCount = 0
		if ActiveAuras["Rejuvenation"] then hotCount = hotCount + 1 end
		if ActiveAuras["Regrowth"] then hotCount = hotCount + 1 end
		if ActiveAuras["Lifebloom"] then hotCount = hotCount + 1 end
		if ActiveAuras["Wild Growth"] then hotCount = hotCount + 1 end
		if ActiveAuras["Tranquility"] then hotCount = hotCount + 1 end
		if hotCount > 0 then
			local bonus = 0
			--Multiplicative - 3.3.3
			calculation.dmgM = calculation.dmgM * (1.2 + bonus)
		end
	end
	--self.Calculation["Swiftmend"] = function( calculation, ActiveAuras, Talents )
		--[[if Talents["Efflorescence"] then
			calculation.hybridDotDmg = Talents["Efflorescence"] * calculation.maxDam
			calculation.SPBonus_dot = Talents["Efflorescence"] * calculation.SPBonus
			calculation.eDuration = 7
			calculation.sTicks = 1
			calculation.aoe = 3
			calculation.hybridCanCrit = false
			if Talents["Master Shapeshifter"] and (GetShapeshiftForm() == 0 or ActiveAuras["Tree of Life"]) then
				calculation.dmgM_dot = calculation.dmgM_dot * 1.04
			end
		end
	end --]]
	--self.Calculation["Rejuvenation"] = function( calculation, ActiveAuras, Talents, spell )
		--Glyph of Rejuvenation - 4.0
		--[[if self:HasGlyph(54754) then
			--Additive - 4.0
			calculation.dmgM_Add = calculation.dmgM_Add + 0.1
		end --]]
		--[[if Talents["Gift of the Earthmother"] then
			calculation.eDot = false
			calculation.hybridDotDmg = calculation.maxDam
			calculation.SPBonus_dot = calculation.SPBonus
			calculation.dotToDD = Talents["Gift of the Earthmother"]
			calculation.bDmgM = calculation.hits * Talents["Gift of the Earthmother"] * calculation.bDmgM
			calculation.SPBonus = calculation.hits * Talents["Gift of the Earthmother"] * calculation.SPBonus
			calculation.hits = nil
		end --]]
	--end
	self.Calculation["Wild Growth"] = function( calculation, ActiveAuras )
		--Glyph of Wild Growth - 4.0
		if self:HasGlyph(62970) then
			calculation.aoe = calculation.aoe + 1
			calculation.cooldown = calculation.cooldown +2
		end
		if ActiveAuras["Tree of Life"] then
			calculation.aoe = calculation.aoe + 2
		end
	end
	self.Calculation["Moonfire"] = function( calculation, _, Talents )
		--Glyph of Moonfire - 4.0 (additive - 3.3.3)
		if self:HasGlyph(54829) then
			calculation.dmgM_dot_Add = calculation.dmgM_dot_Add + 0.2
		end
	end
	self.Calculation["Starfall"] = function( calculation )
		--Glyph of Focus - 4.0
		--[[if self:HasGlyph(62080) then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.1
		end --]]
		--Glyph of Starfall - 4.0
		if self:HasGlyph(54828) then
			calculation.cooldown = calculation.cooldown - 30
		end
		if calculation.targets > 1 then
			calculation.hits = 20
		end
	end
	self.Calculation["Wrath"] = function( calculation, ActiveAuras )
		--Glyph of Wrath - 4.0 -- Multiplicative??
		if self:HasGlyph(54756) then
			calculation.dmgM = calculation.dmgM * 1.1
		end
		if self:GetSetAmount("T13 Moonkin") >= 2 and ActiveAuras["Insect Swarm"] then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.03
		end		
		if ActiveAuras["Tree of Life"] then
			calculation.dmgM = calculation.dmgM * 1.3
		end
	end
	self.Calculation["Starfire"] = function( calculation, ActiveAuras, Talents, spell )
		if self:GetSetAmount("T13 Moonkin") >= 2 and ActiveAuras["Insect Swarm"] then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.03
		end		
	end
	self.Calculation["Starsurge"] = function( calculation, ActiveAuras )
		if self:GetSetAmount("T13 Moonkin") >= 2 and ActiveAuras["Insect Swarm"] then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.03
		end
		if self:GetSetAmount("T13 Moonkin") >= 4 then
			calculation.cooldown = calculation.cooldown - 5
		end
	end	
	--[[self.Calculation["Insect Swarm"] = function( calculation )
		--Glyph of Insect Swarm - 4.0 (additive - 3.3.3)
		if self:HasGlyph(54830) then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.3
		end 
	end --]]
 	self.Calculation["Maul"] = function( calculation, ActiveAuras, Talents, spell )
		if ActiveAuras["Bleeding"] or ActiveAuras["Lacerate"] then
			--Multiplicative - 3.3.3
			calculation.dmgM = calculation.dmgM * 1.2
		end
		--Glyph of Maul - 4.0
		if self:HasGlyph(54811) then
			if calculation.targets >= 2 then
				calculation.aoe = 2
				calculation.aoeM = 0.5
			end
		end
		if self:GetSetAmount("T12 Feral") >= 4 then
			--TODO: Fire Damage?
			calculation.dmgM = calculation.dmgM * 1.1
		end				
	end
	self.Calculation["Ferocious Bite"] = function( calculation, ActiveAuras, Talents )
		if ActiveAuras["Bleeding"] or ActiveAuras["Lacerate"] then
			calculation.critPerc = calculation.critPerc + 25
		end
		local energy = math_min(25,UnitPower("player", 3) - calculation.actionCost)
		if energy > 0 then
			calculation.dmgM = calculation.dmgM * (1 + energy/25)
			calculation.actionCost = calculation.actionCost + energy
		end
	end
	--[[self.Calculation["Rip"] = function( calculation )
		--Glyph of Rip - 4.0 - Additive??
		if self:HasGlyph(54818) then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.15
		end 
	end --]]
	self.Calculation["Faerie Fire"] = function( calculation, ActiveAuras )
		if not ActiveAuras["Bear Form"] then
			calculation.zero = true
		end
	end
	self.Calculation["Mangle (Bear)"] = function( calculation, ActiveAuras )
		if ActiveAuras["Berserk"] then
			calculation.aoe = 3
			calculation.cooldown = 0
		end
		--Glyph of Mangle 4.0 - (multiplicative with Savage Fury - 3.3.3)
		--[[if self:HasGlyph(54813) then
			calculation.dmgM = calculation.dmgM * 1.1
		end --]]
		if self:GetSetAmount("T12 Feral") >= 4 then
			--TODO: Fire Damage?
			calculation.dmgM = calculation.dmgM * 1.1
		end
	end
	self.Calculation["Mangle (Cat)"] = function( calculation )
		--Glyph of Mangle 4.0 - (multiplicative with Savage Fury - 3.3.3)
		--[[if self:HasGlyph(54813) then
			calculation.dmgM = calculation.dmgM * 1.1
		end --]]
		if self:GetSetAmount("T12 Feral") >= 4 then
			--TODO: Fire Damage?
			calculation.dmgM = calculation.dmgM * 1.1
		end			
	end
	--[[self.Calculation["Lacerate"] = function( calculation )
		--Glyph of Lacerate - 4.0
		if self:HasGlyph(94382) then
			calculation.critPerc = calculation.critPerc + 5
		end
	end --]]
	--[[self.Calculation["Swipe (Bear)"] = function( calculation )
		if self:GetSetAmount("T10 Feral") >= 2 then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.2
		end
	end --]]
	--[[self.Calculation["Rake"] = function( calculation )
		if self:GetSetAmount("T11 Feral") >= 2 then
			calculation.dmgM_Extra_Add = calculation.dmgM_Extra_Add + 0.1
		end
	end --]]
	self.Calculation["Shred"] = function( calculation, ActiveAuras, Talents, _, baseSpell )
		if ActiveAuras["Bleeding"] or ActiveAuras["Lacerate"] then
			--Multiplicative - 3.3.3
			calculation.dmgM = calculation.dmgM * 1.2
		end
		if self:GetSetAmount("T12 Feral") >= 4 then
			--TODO: Fire Damage?
			calculation.dmgM = calculation.dmgM * 1.1
		end		
	end
	self.Calculation["Shred!"] = self.Calculation["Shred"]
	self.Calculation["Ravage"] = function( calculation, _, Talents )
		if UnitHealth("target") ~=0 and (UnitHealth("target") / UnitHealthMax("target")) >= 0.80 then
			calculation.critPerc = calculation.critPerc + 50
		end
	end
	self.Calculation["Ravage!"] = self.Calculation["Ravage"]
	--[[self.Calculation["Pulverize"] = function( calculation, ActiveAuras )
		--TODO: Verify
		local bonus = ActiveAuras["Lacerate"] or 0
		calculation.minDam = calculation.minDam * bonus
		calculation.maxDam = calculation.maxDam * bonus
	end --]]
	self.SetBonuses["T12 Feral"] = { 71486, 71487, 71488, 71489, 71490 }
	self.SetBonuses["T13 Moonkin"] = { 77018, 77019, 77020, 77021, 77022, 78662, 78676, 78696, 78714, 78744, 78757, 78771, 78791, 78809, 78839,  }
--AURA
--Player
	--Moonkin form - 4.0
	self.PlayerAura[GetSpellInfo(24858)] = { ActiveAura = "Moonkin Form", ID = 25868, NoManual = true }
	--Tree of Life - 4.0
	self.PlayerAura[GetSpellInfo(33891)] = { ActiveAura = "Tree of Life", ID = 33891, NoManual = true }
	--Cat Form - 4.0
	self.PlayerAura[GetSpellInfo(768)] = { ActiveAura = "Cat Form", ID = 768, NoManual = true }
	--Bear Form - 4.0
	self.PlayerAura[GetSpellInfo(5487)] = { ActiveAura = "Bear Form", ID = 5487, NoManual = true }
	--Lunar shower - 4.0 (Moonfire, Sunfire - needs spellIDs to get paired up correctly)
	self.PlayerAura[GetSpellInfo(81006)] = { Spells = { 8921, 93402 }, Apps = 3, Ranks = 3, ID = 81006, Value = 0.15, Multiply = true, ModType = "dmgM_dd", NoManual = true }
	--Fury of Stormrage - 4.0
	self.PlayerAura[GetSpellInfo(81093)] = { Update = true, Spells = "Starfire" }
	--Nature's Bounty
	self.PlayerAura[GetSpellInfo(96206)] = { Update = true, Spells = "Nourish" }
	--Rejuvenation - 4.0
	self.PlayerAura[GetSpellInfo(774)] = { Update = true, Spells = "Nourish", ID = 774 }
	--Regrowth - 4.0
	self.PlayerAura[GetSpellInfo(16561)] = { Update = true, Spells = "Nourish", ID = 16561 }
	--Lifebloom - 4.0
	self.PlayerAura[GetSpellInfo(33763)] = { Update = true, Spells = "Nourish", ID = 33763 }
	--Wild Growth - 4.0
	self.PlayerAura[GetSpellInfo(48438)] = { Update = true, Spells = "Nourish", ID = 48438 }
	--Tranquility - 4.0
	self.PlayerAura[GetSpellInfo(21791)] = { Update = true, Spells = "Nourish", ID = 21791 }
	--Frenzied Regeneration - 4.0
	self.PlayerAura[GetSpellInfo(22842)] = { School = "Healing", ActiveAura = "Frenzied Regeneration", ID = 22842 }
	--Savage Roar 4.0
	--self.PlayerAura[GetSpellInfo(52610)] = { ID = 52610, School = "Physical", Melee = true, NoManual = true, ModType =
	--	function( calculation, _, _, index )
	--		calculation.dmgM_Add = calculation.dmgM_Add + 0.3
--		end
--	}
	--Tiger's Fury 4.0 - (needs to be divided out of spell modifiers)
	self.PlayerAura[GetSpellInfo(5217)] = { School = "Damage Spells", Multiply = true, ModType = "dmgM_Physical", Value = 0.15, NoManual = true, }
	--Eclipse (Solar) 4.0
	self.PlayerAura[GetSpellInfo(48517)] = { School = { "Nature", "Spellstorm" }, ActiveAura = "Eclipse", ID = 48517, ModType =
		function( calculation, _, Talents )
			--TODO: Additive or multiplicative?
			calculation.dmgM = calculation.dmgM * 1.15
		end
	}
	--Eclipse (Lunar) 4.0
	self.PlayerAura[GetSpellInfo(48518)] = { School = { "Arcane", "Spellstorm" }, ActiveAura = "Eclipse", ID = 48518, ModType =
		function( calculation, _, Talents )
			--TODO: Additive or multiplicative?
			calculation.dmgM = calculation.dmgM * 1.15
		end
	}
	--Berserk 4.0
	self.PlayerAura[GetSpellInfo(50334)] = { ActiveAura = "Berserk", ID = 50334, ModType =
		function( calculation, _, _, index )
			if not index and calculation.requiresForm == 3 then
				calculation.actionCost = calculation.actionCost * 0.5
			end
		end
	}
	--Nature's Swiftness 4.1
	self.PlayerAura[GetSpellInfo(17116)] = { Spells = { "Nourish", "Healing Touch", "Regrowth" }, Value = 0.5, ID = 17116, NoManual = true }
	--Harmony
	self.PlayerAura[GetSpellInfo(100977)] = { School = "Healing", ActiveAura = "Harmony", ID = 100977, NoManual = true, Value = 0.1, ModType = "dmgM_dot" }
--Target
	--Insect Swarm (For t13 bonus)
	self.TargetAura[GetSpellInfo(5570)] = { Spells = { "Starfire", "Starsurge", "Wrath" }, ActiveAura = "Insect Swarm", ID = 5570 }
	--Rejuvenation - 4.0
	self.TargetAura[GetSpellInfo(774)] = { School = "Healing", ActiveAura = "Rejuvenation", Index = true, SelfCastBuff = true, ID = 774 }
	--Regrowth - 4.0
	self.TargetAura[GetSpellInfo(16561)] = { School = "Healing", ActiveAura = "Regrowth", Index = true, SelfCastBuff = true, ID = 16561 }
	--Lifebloom - 4.0
	self.TargetAura[GetSpellInfo(33763)] = { School = "Healing", ActiveAura = "Lifebloom", SelfCastBuff = true, ID = 33763 }
	--Wild Growth - 4.0
	self.TargetAura[GetSpellInfo(48438)] = { School = "Healing", ActiveAura = "Wild Growth", SelfCastBuff = true, ID = 48438 }
	--Tranquility - 4.0
	self.TargetAura[GetSpellInfo(21791)] = { School = "Healing", ActiveAura = "Tranquility", SelfCastBuff = true, ID = 21791 }
	--Lacerate 4.0
	self.TargetAura[GetSpellInfo(33745)] = { Spells = { "Pulverize", "Shred", "Maul", "Ferocious Bite" }, ActiveAura = "Lacerate", Apps = 3, SelfCast = true, ID = 33745 }

--Bleed effects
	--Deep Wound - 4.0 (TODO: Verify this contains all important ones)
	self.TargetAura[GetSpellInfo(43104)] = 	{ ActiveAura = "Bleeding", Manual = "Bleeding", Spells = { "Shred", "Maul", "Ferocious Bite" }, ID = 59881 }
	--Pounce - 4.0
	self.TargetAura[GetSpellInfo(9005)] = 	self.TargetAura[GetSpellInfo(43104)]
	--Rip - 4.0
	self.TargetAura[GetSpellInfo(1079)] = 	self.TargetAura[GetSpellInfo(43104)]
	--Rake - 4.0
	self.TargetAura[GetSpellInfo(59881)] = 	self.TargetAura[GetSpellInfo(43104)]
	--Rend - 4.0
	self.TargetAura[GetSpellInfo(94009)] = 	self.TargetAura[GetSpellInfo(43104)]
	--Garrote - 4.0
	self.TargetAura[GetSpellInfo(703)] = 	self.TargetAura[GetSpellInfo(43104)]
	--Rupture - 4.0
	self.TargetAura[GetSpellInfo(1943)] = 	self.TargetAura[GetSpellInfo(43104)]
	--Piercing Shots - 4.0
	self.TargetAura[GetSpellInfo(53234)] = 	self.TargetAura[GetSpellInfo(43104)]

        --Dream of Cenarius Healing version (Excludes Tranquility)
        --self.PlayerAura[GetSpellInfo(108382)] = { ID=108382, BuffID=108382, School = "Healing", Not = "Tranquility", Value = 0.3, ModType = "dmgM" }
        self.PlayerAura[GetSpellInfo(108382)] = {  ModType = 
		function( calculation, _, _, _, index )
			local id = select(11,UnitAura("player","Dream of Cenarius",nil,"PLAYER"))
			if id == 108382 then
      				if calculation.School == "Healing" and calculation.spellName ~= "Tranquility" then
					calculation.dmgM = calculation.dmgM * 1.3
				end
			elseif id == 108381 then
     				if calculation.melee then
					calculation.dmgM = calculation.dmgM * 1.25
				elseif calculation.spellName == "Moonfire" or calculation.spellName == "Sunfire" then
					calculation.dmgM = calculation.dmgM * 1.5
				end
			end
		end
	}

	local bear = GetSpellInfo(5487)
	local bear_rank = select(2,GetSpellInfo(33878))
	local cat = GetSpellInfo(768)
	local cat_rank = select(2,GetSpellInfo(33876))
	self.spellInfo = {
		[GetSpellInfo(5176)] = {
			["Name"] = "Wrath",
			["ID"] = 5176,
			["Data"] = { 2.2379, 0.25, 1.11899, ["ct_min"] = 1500, ["ct_max"] = 2500 },
			[0] = { School = "Nature", },
			[1] = { 0, 0 },
		},
		[GetSpellInfo(16914)] = {
			["Name"] = "Hurricane",
			["ID"] = 16914,
			["Data"] = { 0.31, 0, 0.31 },
			[0] = { School = "Nature", Hits = 10, Channeled = 10, AoE = true, },
			[1] = { 0, 0 },
		},
		[GetSpellInfo(5570)] = {
			["Name"] = "Insect Swarm",
			["ID"] = 5570,
			["Data"] = { 0.416, 0, 0.397 },
			[0] = { School = "Nature", Hits = 6, eDot = true, eDuration = 12, sTicks = 2, },
			[1] = { 0, 0 },
		},
		[GetSpellInfo(8921)] = {
			["Name"] = "Moonfire",
			["ID"] = 8921,
			["Data"] = { 0.5709, 0.20, 0.2399, 0.2399, 0, 0.2399 },
			[0] = { School = "Arcane", Hits_dot = 7, eDuration = 14, sTicks = 2, },
			[1] = { 0, 0, hybridDotDmg = 0 },
		},
		[GetSpellInfo(93402)] = {
			--Sunfire
			["Name"] = "Moonfire",
			["ID"] = 93402,
			["Data"] = { 0.5701, 0.20, 0.2399, 0.2399, 0, 0.2399 },
			[0] = { School = "Nature", Hits_dot = 7, eDuration = 14, sTicks = 2, },
			[1] = { 0, 0, hybridDotDmg = 0 },
		},
		[GetSpellInfo(2912)] = {
			["Name"] = "Starfire",
			["ID"] = 2912,
			["Data"] = { 3.7269, 0.25, 1.8109, ["ct_min"] = 3500, ["ct_max"] = 3200 },
			[0] = { School = "Arcane", },
			[1] = { 0, 0, },
		},
		[GetSpellInfo(48505)] = {
			["Name"] = "Starfall",
			["ID"] = 48505,
			["Data"] = { 0.527, 0, 0.1169 },
			[0] = { School = "Arcane", Hits = 10, eDot = true, eDuration = 10, AoE = 2, NoPeriod = true, NoDotHaste = true },
			[1] = { 0, 0, },
		},
		[GetSpellInfo(88747)] = {
			["Name"] = "Wild Mushroom",
			["ID"] = 88747,
			["Data"] = { 0.295, 0.19, 0.349 },
			[0] = { School = "Nature", AoE = true },
			[1] = { 0, 0, },
		},
		[GetSpellInfo(78674)] = {
			["Name"] = "Starsurge",
			["ID"] = 78674,
			["Data"] = { 4.1769, 0.319, 2.197 },
			[0] = { School = "Spellstorm", Double = { "Nature", "Arcane" }, Cooldown = 15 },
			[1] = { 0, 0, },
		},
		[GetSpellInfo(5185)] = {
			["Name"] = "Healing Touch",
			["ID"] = 5185,
			["Data"] = { 18.388, 0.166, 1.86, ["ct_min"] = 1500, ["ct_max"] = 3000  },
			[0] = { School = { "Nature", "Healing", }, },
			[1] = { 0, 0 },
		},
		[GetSpellInfo(774)] = {
			["Name"] = "Rejuvenation",
			["ID"] = 774,
			["Data"] = { 3.868, 0, 0.3919 },
			[0] = { School = { "Nature", "Healing", }, Hits = 4, Hits_dot = 4, eDot = true, eDuration = 12, sTicks = 3, },
			[1] = { 0, 0 },
		},
		[GetSpellInfo(8936)] = {
			["Name"] = "Regrowth",
			["ID"] = 8936,
			["Data"] = { 9.4849, 0.1099, 0.958, 0.7189, 0, 0.0729 },
			[0] = { School = { "Nature", "Healing", }, Hits_dot = 3, eDuration = 6, sTicks = 2, },
			[1] = { 0, 0, hybridDotDmg = 0, },
		},
		[GetSpellInfo(740)] = {
			["Name"] = "Tranquility",
			["ID"] = 740,
			["Data"] = { 8.255, 0, 0.8349, 1.409, 0, 0.142  },
			[0] = { School = { "Nature", "Healing", }, Channeled = 8, Hits = 4, Hits_dot = 4, eDuration = 8, sTicks = 2, Cooldown = 480, AoE = 5, HybridAoE = true },
			[1] = { 0, 0, hybridDotDmg = 0 },
		},
		[GetSpellInfo(33763)] = {
			["Name"] = "Lifebloom",
			["ID"] = 33763,
			["Data"] = { 7.455, 0, 0.7519, 0.5669, 0, 0.057 },
			[0] = { School = { "Nature", "Healing" }, Hits_dot = 10, eDuration = 10, sTicks = 1, DotStacks = 3, },
			[1] = { 0, 0, hybridDotDmg = 0, },
		},
		[GetSpellInfo(48438)] = {
			["Name"] = "Wild Growth",
			["ID"] = 48438,
			["Data"] = { 0.9039, 0, 0.092 },
			[0] = { School = { "Nature", "Healing" }, Hits = 7, eDot = true, eDuration = 7, sTicks = 1, Cooldown = 8, AoE = 5 },
			[1] = { 0, 0 },
		},
		[GetSpellInfo(50464)] = {
			["Name"] = "Nourish",
			["ID"] = 50464,
			["Data"] = { 6.0739, 0.15, 0.614 },
			[0] = { School = { "Nature", "Healing" }, },
			[1] = { 0, 0 },
		},
		[GetSpellInfo(18562)] = {
			["Name"] = "Swiftmend",
			["ID"] = 18562,
			["Data"] = { 12.7569, 0, 1.2899 },
			[0] = { School = { "Nature", "Healing" }, Cooldown = 15, HybridAoE = true, HybridAoE_Only = true },
			[1] = { 0, 0, },
		},
		--Feral
		[GetSpellInfo(770)] = {
			["Name"] = "Faerie Fire",
			["ID"] = 770,
			["Data"] = { 0.009 },
			[0] = { Melee = true, School = "Nature", APBonus = 0.302, requiresForm = 1 },
			[1] = { 0 },
		},
		[GetSpellInfo(1079)] = {
			["Name"] = "Rip",
			["ID"] = 1079,
			["Data"] = { 0.103, ["perCombo"] = 0.292 },
			[0] = { Melee = true, APBonus = 0.04845, Hits = 8, ComboPoints = true, requiresForm = 3, eDot = true, eDuration = 16, Ticks = 2, Bleed = true },
			[1] = { 0, PerCombo = 0 },
		},
		[GetSpellInfo(5221)] = {
			["Name"] = "Shred",
			["ID"] = 5221,
			["Data"] = { 0.071 },
			[0] = { WeaponDamage = 5.0, Melee = true, requiresForm = 3, Bleed = true, Armor = true },
			[1] = { 0 },
		},
		[GetSpellInfo(114236)] = {
                        ["Name"] = "Shred!",
                        ["ID"] = 114236,
                        ["Data"] = { 0.071 },
                        [0] = { WeaponDamage = 5.0, Melee = true, requiresForm = 3, Bleed = true, Armor = true },
                        [1] = { 0 },
		},

		[GetSpellInfo(1822)] = {
			["Name"] = "Rake",
			["ID"] = 1822,
			["Data"] = { 0.09, ["extra"] = 0.09 },
			[0] = { Melee = true, APBonus = 0.3, Hits_extra = 5, APBonus_extra = 0.3, E_eDuration = 15, E_Ticks = 3, E_canCrit = true, requiresForm = 3, Bleed = true, BleedExtra = true },
			[1] = { 0, Extra = 0 },
		},
		[GetSpellInfo(22568)] = {
			["Name"] = "Ferocious Bite",
			["ID"] = 22568,
			["Data"] = { 0.456, 0.74, ["perCombo"] = 0.695},
			[0] = { Melee = true, APBonus = 0.196, ComboPoints = true, requiresForm = 3 },
			[1] = { 0, 0, PerCombo = 0 },
		},
		[GetSpellInfo(6785)] = {
			["Name"] = "Ravage",
			["ID"] = 6785,
			["Data"] = { 0.071 },
			[0] = { Melee = true, WeaponDamage = 9.5, requiresForm = 3 },
			[1] = { 0 },
		},
		[GetSpellInfo(81170)] = {
			["Name"] = "Ravage!",
			["ID"] = 81170,
			["Data"] = { 0.071 },
			[0] = { Melee = true, WeaponDamage = 9.5, requiresForm = 3 },
			[1] = { 0 },
		},		
		[GetSpellInfo(9005)] = {
			["Name"] = "Pounce",
			["ID"] = 9005,
			["Data"] = { 0.697 },
			[0] = { Melee = true, APBonus = 0.053, Hits = 6, eDot = true, eDuration = 18, Ticks = 3, Bleed = true, requiresForm = 3, },
			[1] = { 0 },
		},
                [GetSpellInfo(106785)] = {
                        [0] = function(ActiveAuras)
                                if UnitBuff("player", bear) then
                                        return self.spellInfo["Swipe (Bear)"][0], self.spellInfo["Swipe (Bear)"]
                                elseif UnitBuff("player", cat) then
                                        return self.spellInfo["Swipe (Cat)"][0], self.spellInfo["Swipe (Cat)"]
                                end
                        end,
                },
		["Swipe (Bear)"] = {
			["Name"] = "Swipe (Bear)",
			["ID"] = 779,
			["Data"] = { 0.225, 0, 0.225 },
			[0] = { APBonus = 0.225, Melee = true, requiresForm = 1, AoE = true, Cooldown = 3 },
			[1] = { 0, 0, },
		},
		["Swipe (Cat)"] = {
			["Name"] = "Swipe (Cat)",
			["ID"] = 62078,
			["Data"] = { 0 },
			[0] = { WeaponDamage = 4.0, Melee = true, requiresForm = 3, AoE = true },
			[1] = { 0 },
		},
		--Mangle
		[GetSpellInfo(33878)] = {
			[0] = function(ActiveAuras)
				if UnitBuff("player", bear) then
					return self.spellInfo["Mangle (Bear)"][0], self.spellInfo["Mangle (Bear)"]
				elseif UnitBuff("player", cat) then
					return self.spellInfo["Mangle (Cat)"][0], self.spellInfo["Mangle (Cat)"]
				end
			end,
		},
		["Mangle (Bear)"] = {
					["Name"] = "Mangle (Bear)",
					["ID"] = 33878,
					["Data"] = { 0 },
					[0] = { WeaponDamage = 2.8, Melee = true, requiresForm = 1, Cooldown = 6 },
					[1] = { 0 },
		},
		["Mangle (Cat)"] = {
					["Name"] = "Mangle (Cat)",
					["ID"] = 33876,
					["Data"] = { 0.071 },
					[0] = { WeaponDamage = 5.0, Melee = true, requiresForm = 3, },
					[1] = { 0 },
		},
		[GetSpellInfo(6807)] = {
					["Name"] = "Maul",
					["ID"] = 6807,
					[0] = { WeaponDamage = 1.1, Melee = true, requiresForm = 1, Bleed = true, Armor = true, Cooldown = 3 },
		},		
		--BUG: Blizzard tooltip values for base and combo are too low. Real values seem to be increased by about 155%. Check when Blizzard upates tooltip
		[GetSpellInfo(22570)] = {
					["Name"] = "Maim",
					["ID"] = 22570,
					["Data"] = { 0.075, ["perCombo"] = 0.179, },
					[0] = { Melee = true, WeaponDamage = 0.5, ComboPoints = true, requiresForm = 3, Cooldown = 10 },
					[1] = { 0, 0, PerCombo = 0 },
		},
		[GetSpellInfo(33745)] = {
					["Name"] = "Lacerate",
					["ID"] = 33745,
					["Data"] = { 0 },
					[0] = { Melee = true, APBonus = 0.0616, Hits_extra = 5, APBonus_extra = 0.0512, E_eDuration = 15, E_Ticks = 3, E_canCrit = true, BleedExtra = true, requiresForm = 1 },
					[1] = { 0, Extra = 0 },
		},
		[GetSpellInfo(77758)] = {
					["Name"] = "Thrash (Bear)",
					["ID"] = 77758,
					["Data"] = {  1.125, ["extra"] = 0.627 },
					[0] = { Melee = true, APBonus = 0.191, Hits_extra = 3, APBonus_extra = 1.128, E_eDuration = 16, E_Ticks = 2, E_canCrit = true, requiresForm = 1, Cooldown = 6, E_AoE = true },
					[1] = { 0, 0, Extra = 0 },
		},
                [GetSpellInfo(106830)] = {
                                        ["Name"] = "Thrash (Cat)",
                                        ["ID"] = 106830,
                                        --["Data"] = { 1.125 },
                                        --[0] = { Melee = true, APBonus=0.191, Hits_extra = 5, APBonus_extra = 0.6269, E_eDuration = 15, E_Ticks = 3, E_canCrit = true, requiresForm = 3, E_AoE = true, Bleed = true },
                                        --[1] = { 0, 0, Extra = 0 },

		                        ["Data"] = { 1.125, ["extra"] = "0.627" },
		                        [0] = { Melee = true, APBonus = 0.191, Hits_extra = 5, APBonus_extra = 0.141, E_eDuration = 15, E_Ticks = 3, E_canCrit = true, requiresForm = 3, Bleed = true, BleedExtra = true },
                		        [1] = { 0, Extra = 0 },


                },
		--Symbiosis
		[GetSpellInfo(122282)] = {
					["Name"] = "Death Coil",
					["ID"] = 122282,
					["Data"] = { 0.997 },
					[0] = { School = Shadow, Melee = true, APBonus = 0.495 },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(110701)] = {
					["Name"] = "Consecrate",
					["ID"] = 110701,
					["Data"] = { 0, 0, 0.04 },
					[0] = { School = Nature, Melee = true, Cooldown = 30, AoE = true, APBonus = 0.04, Hits_extra = 2, E_eDuration = 10, E_Ticks = 5, E_canCrit = true },
					[1] = { 0, 0 }, 
		},
		-- Data supported by simulationcraft (Spirit Bite = Bonus of 1 from the scaler data, plus 1 AP = 1 dmg) 120 second CD.
		[GetSpellInfo(110807)] = {
					["Name"] = "Feral Spirit",
					["ID"] = 110807,
					["Data"] = { 1 },
					[0] = { APBonus = 1, Cooldown = 120 },
					[1] = { 0 , 0 },
		}, 
	}
	self.talentInfo = {
	--FERAL:
		--Nurturing Instinct
		[GetSpellInfo(33872)] = { [1] = { Effect = 0.5, Caster = true, Spells = "Healing", ModType = "Nurturing Instinct" }, },
	--RESTORATION:
		--Blessing of the Grove (additive - 4.0)
		--Swift Rejuvenation
		[GetSpellInfo(33886)] = { [1] = { Effect = -0.5, Caster = true, Spells = "Rejuvenation", ModType = "castTime" }, },
		--Naturalist in 5.2
		[GetSpellInfo(17073)] = { [1] = { Spells = "Healing", Value = 0.1, ModType = dmgM }, },
		--Heart of the Wild talent
		[GetSpellInfo(108288)] = { [1] = { Effect = 0.06, Spells = "All", Multiply = true, NoManual = true, ModType =  { "agiM", "intM" }, }, },
	}
end
